@@ -2,14 +2,14 @@ pub mod attribute;
 pub mod instance;
 pub mod object;
 
-use crate::Result;
-use nom::{bytes::complete::tag, IResult};
+use crate::{Result, TailwindBuilder};
 use std::{
     cmp::Ordering,
     collections::{BTreeSet, HashSet},
     fmt::{Debug, Display, Formatter, Write},
     hash::{Hash, Hasher},
 };
+use tailwind_error::nom::{bytes::complete::tag, IResult};
 use text_utils::indent;
 
 /// Tailwind Parsed Result
@@ -17,26 +17,40 @@ pub type ParsedItem<'a> = IResult<&'a str, Box<dyn TailwindInstance>>;
 /// Tailwind Parsed Result
 pub type ParsedList<'a> = IResult<&'a str, HashSet<Box<dyn TailwindInstance>>>;
 
+#[allow(unused_variables)]
 pub trait TailwindInstance {
     /// used to deduplication and marking
     fn id(&self) -> String;
-    // const ID: &'static str;
 
-    fn selectors(&self) -> String {
+    fn boxed(self) -> Box<dyn TailwindInstance>
+    where
+        Self: Sized,
+        Self: 'static,
+    {
+        Box::new(self)
+    }
+    /// const ID: &'static str;
+    fn selectors(&self, ctx: &TailwindBuilder) -> String {
         format!(".{}", self.id())
     }
-    fn attributes(&self) -> BTreeSet<CssAttribute> {
+    ///
+    fn attributes(&self, ctx: &TailwindBuilder) -> BTreeSet<CssAttribute> {
         BTreeSet::default()
     }
-
-    fn write_css(&self, f: &mut (dyn Write)) -> Result<()> {
-        writeln!(f, "{} {{", self.selectors())?;
-        for item in self.attributes() {
+    /// write css to buffers
+    fn write_css(&self, f: &mut (dyn Write), ctx: &TailwindBuilder) -> Result<()> {
+        writeln!(f, "{} {{", self.selectors(ctx))?;
+        for item in self.attributes(ctx) {
             writeln!(f, "{}", indent(item.to_string(), 4))?
         }
         writeln!(f, "}}")?;
         Ok(())
     }
+    /// Build css ast
+    #[track_caller]
+    fn build_css(&self, ctx: &TailwindBuilder) {
+        panic!("TODO: build css AST")
+    }
 }
 
 ///
